@@ -14,24 +14,24 @@ def build_config() -> dict[str, str]:
     """
     return dict(
         # Python settings
-        python_version="3.11",
-        python_install_dir=r"C:/msys64/clangarm64/lib/python3.11/site-packages/",
+        python_version="3.12",
+        python_install_dir=r"C:/msys64/clangarm64/lib/python3.12/site-packages/",
         python_path=r"C:/msys64/clangarm64/bin/python.exe",
 
         # Package versions
         contourpy_version="1.3.0",
-        meson_version="1.5.1",
-        mesonpy_version="0.16.0",
-        pybind11_version="2.13.5",
+        meson_version="1.6.0",
+        mesonpy_version="0.17.1",
+        pybind11_version="2.13.6",
 
         # Misc meson settings
         meson_backend="ninja",
-        build_dir=r"C:/M/B/src/python-build-CLANGARM64/.mesonpy-v8p7s2xn/lib/contourpy/util",
+        build_dir=r"C:/M/B/src/python-build-CLANGARM64/.mesonpy-2_1zfqre/lib/contourpy/util",
         source_dir=r"C:/M/B/src/python-build-CLANGARM64/lib/contourpy/util",
         cross_build="False",
 
         # Build options
-        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md --native-file=C:/M/B/src/python-build-CLANGARM64/.mesonpy-v8p7s2xn/meson-python-native-file.ini",
+        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md --native-file=C:/M/B/src/python-build-CLANGARM64/.mesonpy-2_1zfqre/meson-python-native-file.ini",
         buildtype="release",
         cpp_std="c++17",
         debug="False",
